
#include <unistd.h>
#include <getopt.h>
#include <libintl.h>
#include <locale.h>

#include "panacmds.h"


// common options for all commands
//
void display_common_usage()
{
  cout  << gettext("common options:")
<< endl << gettext("   -v level : sets verbose level, 0 for nothing.")
<< endl << gettext("   -w, --warning : consider warnings to be errors and abort command.")
<< endl;
}


// panainit usage
//
void display_panainit_usage()
{
  cout  << gettext("usage:")
<< endl << gettext("   panainit {-h --help}") 
<< endl << gettext("   panainit [-b --base-file basepath] {-u --unique-base url}")
<< endl << gettext("   panainit [-b --base-file basepath] {-s --string-base phrase}")
<< endl << gettext("   panainit [-b --base-file basepath] {-r --random-base}")
<< endl << endl;
display_common_usage();
}


// panainit command
//
int main( int argc, char **argv)
{
	char kind = 0;
	char * id = 0;
	char * base = 0;


	// language initialization
	//
	setlocale( LC_MESSAGES, "");
	bindtextdomain( PACKAGE, PACKAGE_ROOT_DIRECTORY);
	textdomain( PACKAGE);


	// Process command-line options
	//
	while (1)
	{
		int short_option;	// Short option character

		// Long options declaration & short options mappings
		//
		static struct option long_options[] =
		{
			{ "base-file", 1, NULL, 'b' },
			{ "unique-base", 1, NULL, 'u' },
			{ "string-base", 1, NULL, 's' },
			{ "random-base", 0, NULL, 'r' },
			{ "warning", 0, NULL, 'w' },
			{ "help", 0, NULL, 'h' },
			{ 0, 0, 0, 0 }
		};

		// Check end of option list
		//
		if ((short_option = getopt_long (argc, argv, "b:u:s:rv:wh", 
			long_options, NULL)) == -1) break;

		// Process short option
		//
		switch (short_option)
		{
			case 'b':
				base = strdup(optarg);
				break;
			case 'u':
				kind = 'u';
				id = strdup(optarg);
				break;
			case 's':
				kind = 's';
				id = strdup(optarg);
				break;
			case 'r':
				kind = 'r';
				break;
			case 'w':
				// setting warnings to errors
				//
				PANA_warning_to_error = 1;
				break;
			case 'h':
				display_panainit_usage();
				exit(0);
				break;
			case 'v':
				// setting debug level from verbose
				//
				PANA_debug_level = (int) strtol( optarg, 0, 10);
				break;
			case ':':
				cerr << gettext("panainit command: missing parameter on '");
				cerr << argv[optind] << "'\n";
				exit(1);
				break;
			case '?':
				cerr << gettext("panainit command: extraneous parameter '");
				cerr << argv[optind] << "'\n";
				exit(1);
				break;
			default:
				cerr << gettext("panainit command: unexpected option '");
				cerr << short_option << "' ";
				cerr << gettext("[internal error]") << endl;
				exit(2);
		}
	}

	// Check for no more arguments 
	//
	if (optind != argc)
	{
		cerr << gettext("panainit command: illegal number of arguments.") << endl;
		exit(1);
	}

	// call panainit fuction
	//
	if ( panainit( kind, id, base) != 0)
	{
//		cerr << gettext("panainit command: internal error") << endl;
		exit(1);
	}
	
	// free resources
	//
	if ( base != 0) free(base);
	if ( id != 0) free(id);

	return 0;
}


