
#include <unistd.h>
#include <getopt.h>
#include <libintl.h>
#include <locale.h>

#include "panacmds.h"


// common options for all commands
//
void display_common_usage()
{
  cout  << gettext("common options:")
<< endl << gettext("   -v level : sets verbose level, 0 for nothing.")
<< endl << gettext("   -w, --warning : consider warnings to be errors and abort command.")
<< endl;
}


// panajoin usage
//
void display_panajoin_usage()
{
  cout  << gettext("usage:")
<< endl << gettext("   panajoin {-h --help}")
<< endl << gettext("   panajoin [-o --older] [-c --contents-file contentspath] sourceFile targetFile")
<< endl << endl;
display_common_usage();
}


// panajoin command
//
int main( int argc, char **argv)
{
	int older = 0;
	char * contents = 0;

	char * source, * target;


	// language initialization
	//
	setlocale( LC_MESSAGES, "");
	bindtextdomain( PACKAGE, PACKAGE_ROOT_DIRECTORY);
	textdomain( PACKAGE);


	// Process command-line options
	//
	while (1)
	{
		int short_option;	// Short option character

		// Long options declaration & short options mappings
		//
		static struct option long_options[] =
		{
			{ "older", 0, NULL, 'o' },
			{ "contents-file", 1, NULL, 'c' },
			{ "warning", 0, NULL, 'w' },
			{ "help", 0, NULL, 'h' },
			{ 0, 0, 0, 0 }
		};

		// Check end of option list
		//
		if ((short_option = getopt_long (argc, argv, "oc:v:wh", 
			long_options, NULL)) == -1) break;

		// Process short option
		//
		switch (short_option)
		{
			case 'o':
				older = 1;
				break;
			case 'c':
				contents = strdup(optarg);
				break;
			case 'w':
				// setting warnings to errors
				//
				PANA_warning_to_error = 1;
				break;
			case 'h':
				display_panajoin_usage();
				exit(0);
				break;
			case 'v':
				// setting debug level from verbose
				//
				PANA_debug_level = (int) strtol( optarg, 0, 10);
				break;
			case ':':
				cerr << gettext("panajoin command: missing parameter on '");
				cerr << argv[optind] << "'\n";
				exit(1);
				break;
			case '?':
				cerr << gettext("panajoin command: extraneous parameter '");
				cerr << argv[optind] << "'\n";
				exit(1);
				break;
			default:
				cerr << gettext("panajoin command: unexpected option '");
				cerr << short_option << "' ";
				cerr << gettext("[internal error]") << endl;
				exit(2);
		}
	}

	// Retrieve source and target file from command-line
	//
	if (optind + 2 == argc)
	{
		source = argv[optind];
		target = argv[optind+1];
	}
	else
	{
		cerr << gettext("panajoin command: illegal number of arguments.") << endl;
		exit(1);
	}

	// call panajoin fuction
	//
	if ( panajoin(target, source, contents, older) != 0)
	{
		exit(1);
	}

	// free resources
	//
	if ( contents != 0) free(contents);

	return 0;
}


